@@ -97,7 +97,9 @@ def download_lookup(filename: str, keep_in_memory: bool = True):
     numpy.recarray
         The `numpy.recarray` converted from the csv content.
     """
-    def load(): return _recfromcsv(_rewrite_csv_text_as_tab(_download_lookup_data(filename)))
+    def load():
+        data = _download_lookup_data(filename)
+        return _recfromcsv(_rewrite_csv_text_as_tab(data)) if data else None
 
     try:
         return _memory_wrapper(filename, load) if keep_in_memory else load()
