@@ -1,6 +1,8 @@
+from typing import Union, List
 from hestia_earth.schema import TermTermType, NodeType
 
 _LINKED_NODE_KEYS = {
+    NodeType.SOURCE.value: ['name'],
     NodeType.TERM.value: ['name', 'termType', 'units']
 }
 
@@ -45,7 +47,7 @@ def find_term_match(values: list, term_id: str, default_val={}):
     return next((v for v in values if v.get('term', {}).get('@id') == term_id), default_val)
 
 
-def filter_list_term_type(values: list, term_type: TermTermType) -> list:
+def filter_list_term_type(values: list, term_type: Union[TermTermType, List[TermTermType]]) -> list:
     """
     Filters the values by filtering by the `term.termType` property.
 
@@ -53,15 +55,16 @@ def filter_list_term_type(values: list, term_type: TermTermType) -> list:
     ----------
     values : list
         The list to filter. Example: `cycle['inputs']`.
-    term_type : TermTermType
-        The `termType` of the `Term`. Example: `TermTermType.CROP`
+    term_type : TermTermType or List[TermTermType]
+        The `termType` of the `Term`, or a list of `termType`. Example: `TermTermType.CROP`
 
     Returns
     -------
     list
         The filtered list.
     """
-    return list(filter(lambda i: i.get('term', {}).get('termType') == term_type.value, values))
+    term_types = [t.value for t in term_type] if isinstance(term_type, list) else [term_type.value]
+    return list(filter(lambda i: i.get('term', {}).get('termType') in term_types, values))
 
 
 def find_primary_product(cycle: dict) -> dict:
