@@ -9,8 +9,7 @@ def _load_from_folder(folder: str, key: str):
     try:
         with open(os.path.join(folder, key)) as f:
             return f.read().encode('utf-8')
-    except Exception as e:
-        print(str(e))
+    except Exception:
         # in case the file does not exist, should simply return None
         return None
 
